<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>Select</name>
    <message>
        <location filename="../Select.js" line="+216"/>
        <source>Selection Tools</source>
        <translation>Nástroje výběru</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show selection tools</source>
        <translation>Zobrazit nástroje výběru</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Selection Tools Panel</source>
        <translation>Panel nástrojů výběru</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;Select</source>
        <translation>&amp;Výběr</translation>
    </message>
</context>
</TS>
